@@ -8,7 +8,7 @@ model = namedtuple("model", ["url", "model"])
 
 models = {
     "resnet50_2020-07-20": model(
-        url="https://github.com/ternaus/retinaface/releases/download/0.01/retinaface_resnet50_2020-07-20-f168fae3c.zip",  # noqa: E501
+        url="https://github.com/ternaus/retinaface/releases/download/0.01/retinaface_resnet50_2020-07-20-f168fae3c.zip",  # noqa: E501 pylint: disable=C0301
         model=Model,
     )
 }
